durationtools.rational_to_duration_pair_with_specified_integer_denominator
==========================================================================

.. autofunction:: abjad.tools.durationtools.rational_to_duration_pair_with_specified_integer_denominator.rational_to_duration_pair_with_specified_integer_denominator
